# Django Kakebo

A simple site made with django and exploiting the kakebo method.

[IT]
Il Kakebo (giapponese: 家計簿) è un metodo di risparmio e di gestione finanziaria della famiglia nato e sviluppato in Giappone
Una prima copia di un kakebo è stato pubblicato dalla giornalista Motoko Hani (nel 1904).

Letteralmente traducibile come "registro di casa"; ve ne sono di diversi tipi, che modificano la struttura dello stesso, ma l'idea di base è la stessa.

All'inizio del mese: il kakeibo annota le entrate e le spese necessarie per il mese iniziale e decide una sorta di obiettivo di risparmio, aggiungendo eventuli spunti o propositi.
Su base giornaliera: l'utente registra le proprie spese, che vengono sommate alla fine della settimana e alla fine del mese.\
Alla fine del mese: l'utente redige un bilancio di fine mese con eventuali appunti e/o verifica del motivo del non raggiungimento dell'obiettivo imposto all'inizio del mese.

Oltre alle spese e alle entrate, nel Kakebo si scrivono anche: pensieri e osservazioni, con l'obiettivo di aumentare la consapevolezza dei propri consumi.

In questo progetto viene elaborato un sito attraverso python3 (con l'uso del framework django) che riporta lo stesso spirito del Kakebo tradizionale, dando all'utente un'interfaccia pulita e utilizzabile da subito, con la semplice installazione del pacchetto/app.\
Nel pacchetto è presente:
  - 'Home Page' (disattivabile dai settings)
  - app 'user': che permette la gestione dell'utenza (login e registrazione // con eventuale reCAPTCHA)

Per i dettagli, consigliamo di leggere la documentazione

[EN]
The Kakebo (Japanese: 家計簿) is a method of household savings and financial management method originated and developed in Japan.
An early copy of a kakebo was published by journalist Motoko Hani (in 1904).

Literally translatable as "household ledger"; there are different types where the structure changes, but the basic idea is the same.

At the beginning of the month: the user notes the income and expenses needed for the initial month and decides on some sort of savings goal, adding any cues or resolutions.
On a daily basis: the user records his or her expenses, which are added up at the end of the week and at the end of the month.\
At the end of the month: the user draws up an end-of-month balance sheet with any notes and/or verification of why the goal imposed at the beginning of the month was not met.

In addition to expenses and income, also written in the Kakebo are: thoughts and observations, with the goal of increasing awareness of one's consumption.

In this project, a site is developed through python3 (with the use of the django framework) that brings back the same spirit as the traditional Kakebo, giving the user a clean and usable interface right out of the box, with the simple installation of the package/app.\
Included in the package is:
  - 'Home Page' (can be deactivated from settings's project)
  - 'user' app: which allows user management (login and registration // with reCAPTCHA)

For details, we recommend reading the documentation